@@ -184,26 +184,26 @@ def main():
     except:
         pass
 
+def main11():        
+    try: 
 
-try: 
-    
-    main()
+        main()
 
-except KeyboardInterrupt:
-    print("it happen")
-    sys.exit(1)
-except TypeError:
-    #print("[bold red]Check network connection and try again.[/bold red]")
-    sys.exit(1)
-except KeyError:
-    print("[bold red]Use keyboard for selection[/bold red]")
-    sys.exit(1)
-except ValueError:
-    print("[bold red]Use keyboard for selection[/bold red]")
-    sys.exit(1)
-except Exception as e:
-    print(f"[red]{e}[/red]")
-    sys.exit(1)
+    except KeyboardInterrupt:
+        print("it happen")
+        sys.exit(1)
+    except TypeError:
+        #print("[bold red]Check network connection and try again.[/bold red]")
+        sys.exit(1)
+    except KeyError:
+        print("[bold red]Use keyboard for selection[/bold red]")
+        sys.exit(1)
+    except ValueError:
+        print("[bold red]Use keyboard for selection[/bold red]")
+        sys.exit(1)
+    except Exception as e:
+        print(f"[red]{e}[/red]")
+        sys.exit(1)
 
 
 #main()
